analytics

package
v0.0.0-...-a58f080 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 19, 2025 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IdentifyUser

func IdentifyUser(distinctID string, properties map[string]interface{}) error

IdentifyUser updates user properties in PostHog

func InitAnalytics

func InitAnalytics()

InitAnalytics initializes the PostHog client with the configured token

func TrackEvent

func TrackEvent(name string, properties map[string]interface{}, distinctID string) error

TrackEvent sends an event to PostHog with the given properties Returns an error if the tracking failed

func TrackEventWithUser

func TrackEventWithUser(name string, properties map[string]interface{}, user *ent.User) error

TrackEventWithUser sends an event to PostHog associated with a specific user Returns an error if the tracking failed or nil if the user is blacklisted

Types

This section is empty.

Jump to